@@ -793,7 +793,7 @@ class Test:
         self.index += 1
         m0 = regex.match(r'(?P<a>\w)', 'x')
         m1 = regex.match(r'(?<a>\w)', 'x')
-        if m0[:] != m1[:]:
+        if not (m0 and m1 and m0[:] == m1[:]):
             self.record_failure("Failed")
 
     def test_properties(self):
